@@ -1,16 +1,17 @@
 package URI::Fast;
+# ABSTRACT: A fast(er) URI parser
+$URI::Fast::VERSION = '0.35_1'; # TRIAL
 
+$URI::Fast::VERSION = '0.351';use utf8;
 use strict;
 use warnings;
 no strict 'refs';
 
-our $VERSION = '0.34_01';
-
 use Carp;
 use Exporter;
 
 require XSLoader;
-XSLoader::load('URI::Fast', $VERSION);
+XSLoader::load('URI::Fast');
 
 use Exporter 'import';
 
@@ -20,6 +21,8 @@ our @EXPORT_OK = qw(
   decode url_decode
 );
 
+require URI::Fast::IRI;
+
 use overload '""' => sub{ $_[0]->to_string },
              'eq' => sub{ $_[0]->compare($_[1]) };
 
@@ -184,12 +187,23 @@ sub compare {
   return 1;
 }
 
-=encoding UTF8
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 URI::Fast - A fast(er) URI parser
 
+=head1 VERSION
+
+version 0.35_1
+
 =head1 SYNOPSIS
 
   use URI::Fast qw(uri);
@@ -309,6 +323,8 @@ C<?>. The query string may be set in several ways.
 In list context, returns a hash ref mapping query keys to array refs of their
 values (see L</query_hash>).
 
+Both '&' and ';' are treated as separators for key/value parameters.
+
 =head2 frag
 
 The fragment section of the URI, excluding the leading C<#>.
@@ -320,11 +336,15 @@ The fragment section of the URI, excluding the leading C<#>.
 Does a fast scan of the query string and returns a list of unique parameter
 names that appear in the query string.
 
+Both '&' and ';' are treated as separators for key/value parameters.
+
 =head2 query_hash
 
 Scans the query string and returns a hash ref of key/value pairs. Values are
 returned as an array ref, as keys may appear multiple times.
 
+Both '&' and ';' are treated as separators for key/value parameters.
+
 =head2 param
 
 Gets or sets a parameter value. Setting a parameter value will replace existing
@@ -341,14 +361,19 @@ parameter to C<undef> deletes the parameter from the URI.
   # Delete 'foo'
   $uri->param('foo', undef);
 
-An optional third parameter may be specified to control the character used to
-separate key/value pairs.
+Both '&' and ';' are treated as separators for key/value parameters when
+parsing the query string. An optional third parameter explicitly selects the
+character used to separate key/value pairs.
 
   $uri->param('foo', 'bar', ';'); # foo=bar
   $uri->param('baz', 'bat', ';'); # foo=bar;baz=bat
 
-When included, separators in the query string will be normalized to the
-character specified.
+When unspecified, '&' is chosen as the default. I<In either case, all
+separators in the query string will be normalized to the chosen separator>.
+
+  $uri->param('foo', 'bar', ';'); # foo=bar
+  $uri->param('baz', 'bat', ';'); # foo=bar;baz=bat
+  $uri->param('fnord', 'slack');  # foo=bar&baz=bat&fnord=slack
 
 =head2 add_param
 
@@ -359,6 +384,17 @@ altering the original value.
   $uri->add_param('foo', 'bar'); # foo=bar
   $uri->add_param('foo', 'baz'); # foo=bar&foo=baz
 
+This method is simply sugar for calling:
+
+  $uri->param('key', [$uri->param('key'), 'new value']);
+
+As with L</param>, the separator character may be specified as the final
+parameter. The same caveats apply with regard to normalization of the query
+string separator.
+
+  $uri->add_param('foo', 'bar', ';'); # foo=bar
+  $uri->add_param('foo', 'baz', ';'); # foo=bar;foo=baz
+
 =head2 query_keyset
 
 Allows modification of the query string in the manner of a set, using keys
@@ -379,9 +415,8 @@ untouched. A negative value will remove the key and value.
   $uri->query_keyset({foo => 1, baz => 0}); # foo=bar&bat
 
 An optional second parameter may be specified to control the separator
-character used when updating the query string. When the separator is explicitly
-specified, all separators in the query string will be normalized to the
-specified separator.
+character used when updating the query string. The same caveats apply with
+regard to normalization of the query string separator.
 
 =head2 to_string
 
@@ -502,10 +537,6 @@ Thanks to L<ZipRecruiter|https://www.ziprecruiter.com> for encouraging their
 employees to contribute back to the open source ecosystem. Without their
 dedication to quality software development this distribution would not exist.
 
-=head1 AUTHOR
-
-Jeff Ober <sysread@fastmail.fm>
-
 =head1 CONTRIBUTORS
 
 The following people have contributed to this module with patches, bug reports,
@@ -528,17 +559,15 @@ fun of me for naming certain methods too generically.
 
 =back
 
+=head1 AUTHOR
+
+Jeff Ober <sysread@fastmail.fm>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2018 by Jeff Ober.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
-
-package URI::Fast::IRI;
-our @ISA = qw(URI::Fast);
-1;
